"""Common filenames and locations for elevation, meshes and outputs.
This script is the heart of all scripts in the folder
"""
#------------------------------------------------------------------------------
# Import necessary modules
#------------------------------------------------------------------------------

import os
from os.path import join
from os import sep, getenv
from time import localtime, strftime, gmtime
from anuga.utilities.polygon import read_polygon, number_mesh_triangles
from anuga.utilities.system_tools import get_user_name, get_host_name

#------------------------------------------------------------------------------
# Directory setup
#------------------------------------------------------------------------------
# Note: INUNDATIONHOME is the inundation directory, not the data directory.

home = getenv('INUNDATIONHOME')+sep+'data'+sep # Absolute path for data folder
muxhome = getenv('MUXHOME')
user = get_user_name()
host = get_host_name()

# determines time for setting up output directories
time = strftime('%Y%m%d_%H%M%S',localtime()) 
gtime = strftime('%Y%m%d_%H%M%S',gmtime()) 
build_time = time+'_build'
run_time = time+'_run'

# this section needs to be updated to reflect the modelled community.
# Note, the user needs to set up the directory system accordingly
state = 'australia_ph2'
scenario_name = 'sydney'
scenario_folder = 'sydney'

#------------------------------------------------------------------------------
# Initial Conditions
#------------------------------------------------------------------------------
# Model specific parameters. One or all can be changed each time the
# run_scenario script is executed
tide = 0                #0.6
event_number = 7875    # Java 9.3 original
alpha = 0.1             # smoothing parameter for mesh
friction=0.01           # manning's friction coefficient
starttime=0             
finaltime=1000         # final time for simulation

setup='trial'  # Final can be replaced with trial or basic.
               # Either will result in a coarser mesh that will allow a
               # faster, but less accurate, simulation.

if setup =='trial':
    print'trial'
    scale_factor=100
    time_thinning=96
    yieldstep=240
if setup =='basic': 
    print'basic'
    scale_factor=4
    time_thinning=12
    yieldstep=120
if setup =='final': 
    print'final'
    scale_factor=1
    time_thinning=4
    yieldstep=60


#------------------------------------------------------------------------------
# Output Filename
#------------------------------------------------------------------------------
# Important to distinguish each run - ensure str(user) is included!
# Note, the user is free to include as many parameters as desired
output_comment= ('_' + setup + '_' + str(tide)+ '_' + str(event_number) +
                 '_' + str(user))

#------------------------------------------------------------------------------
# Input Data
#------------------------------------------------------------------------------
# ELEVATION DATA
# Used in build_busselton.py
# Format for ascii grids, as produced in ArcGIS + a projection file
#ascii_grid_filenames = ['busselton_v2',   # Topo
#                        'grid_250m_clip'] # Busselton Topo

# Format for point is x,y,elevation (with header)
point_filenames = ['sydney_elevation.txt',
                   'melbourne_elevation.txt']


# LAND - used to set the initial stage/water to be offcoast only
# Used in run_busselton,py
# Format for points easting,northing (no header)
land_initial_conditions_filename = [['initial_condition_extend.csv', 0]],
                                    ['initial_condition_comerong_island.csv', 0],
                                    ['initial_condition_gabo_island.csv', 0],
                                    ['initial_condition_montague_island.csv', 0]]

# BOUNDING POLYGON - for data clipping and estimate of triangles in mesh
# Used in build_busselton.py
# Format for points easting,northing (no header)
bounding_polygon_filename = 'bounding_polygon.csv'

# INTERIOR REGIONS -  for designing the mesh
# Used in run_model.py
# Format for points easting,northing (no header)                    
##interior_regions_data = [['coast_3km_buffer.csv', 50000]]
                         

# BOUNDING POLYGON
# used in build_boundary.py and run_busselton.py respectively
# NOTE: when files are put together the points must be in sequence
# For ease go clockwise!
# Check the run_busselton.py for boundary_tags

# Thinned ordering file from Hazard Map (geographic)
# Format is index,latitude,longitude (with header)
urs_order_filename = 'thinned_boundary_ordering_extend.csv'

# Landward bounding points
# Format easting,northing (no header)
landward_boundary_filename = 'landward_boundary_extend.csv'





#------------------------------------------------------------------------------
# Output Elevation Data
#------------------------------------------------------------------------------
# Output filename for elevation
# this is a combination of all the data generated in build_busselton.py
combined_elevation_basename = scenario_name + '_combined_elevation'

#------------------------------------------------------------------------------
# Directory Structure
#------------------------------------------------------------------------------
anuga_folder = join(home, state, scenario_folder, 'anuga')
topographies_folder = join(anuga_folder, 'topographies')
polygons_folder = join(anuga_folder, 'polygons')
boundaries_folder = join(anuga_folder, 'boundaries')
output_folder = join(anuga_folder, 'outputs')
gauges_folder = join(anuga_folder,'gauges')
meshes_folder = join(anuga_folder, 'meshes')

#------------------------------------------------------------------------------
# Location of input and output data
#------------------------------------------------------------------------------

# The absolute pathname of the all elevation, generated in build_busselton.py
combined_elevation = join(topographies_folder, combined_elevation_basename)

# The absolute pathname of the mesh, generated in run_busselton.py
meshes = meshes_folder + sep + scenario_name + '.msh'

# The absolute pathname for the urs order points, used within build_boundary.py
urs_order = join(boundaries_folder, urs_order_filename)

# The absolute pathname for the landward points of the bounding polygon,
# Used within run_busselton.py)
landward_boundary = join(boundaries_folder, landward_boundary_filename)

# The absolute pathname for the .sts file, generated in build_boundary.py
event_sts = join(boundaries_folder, str(event_number))

# The absolute pathname for the output folder names
# Used for build_busselton.py
output_build = output_folder + sep + build_time + '_' + str(user) 
# Used for run_busselton.py
output_run = output_folder + sep + run_time + output_comment 
# Used by post processing
output_run_time = join(output_run, scenario_name) 


#------------------------------------------------------------------------------
# Reading polygons and creating interior regions
#------------------------------------------------------------------------------

# Create list of land polygons with initial conditions
land_initial_conditions = []
for filename, MSL in land_initial_conditions_filename:
    polygon = read_polygon(join(polygons_folder, filename))
    land_initial_conditions.append([filename, MSL])

### Create list of interior polygons with scaling factor
interior_regions = []
##for filename, maxarea in interior_regions_data:
##    polygon = read_polygon(join(polygons_folder, filename))
##    interior_regions.append([polygon, maxarea*scale_factor])

# Initial bounding polygon for data clipping 
bounding_polygon = read_polygon(join(polygons_folder,
                                     bounding_polygon_filename))
bounding_maxarea = 125000*scale_factor

# Estimate the number of triangles                     
trigs_min = number_mesh_triangles(interior_regions,
                                  bounding_polygon, bounding_maxarea)
print 'min estimated number of triangles', trigs_min
   

